@@ -1,49 +1,33 @@
-/*
- * Copyright James Morse Y2K +1, +2, +3
- * This is GPLed software 
- * please read COPYING
- *
- */
-
-#include <stdio.h>
 #include <math.h>
 #include <stdlib.h>
 #include "terrain.h"
 #include "food.h"
 #include "bug6.h"
 #include "look.h"
-#include "error.h"
 
-/* create intial population */
 void start (void)
 {
-	struct bug *temp = NULL;
-	struct bug *x = NULL;
+	struct bug *temp = NULL, *x = NULL;
 	int loop, loop2;
 
-	/* create bugs */
+	// create bugs
 	for (loop = 1; loop <= NUM_BUGS; loop++)
 	{
-		if ((temp = (struct bug *)malloc(sizeof (struct bug))) == NULL)
-		{
-			fprintf(stderr, "bad malloc in start\n");
-			exit(MB_ST);
-		}
-		temp->race = (char)getrandom(L_RACE, H_RACE);
+		temp = (struct bug *) malloc (sizeof (struct bug));
+		temp->race = (char)getrandom (L_RACE, H_RACE);
 
-		/* don't put bugs on MNT or in WTR */
+		// don't put bugs on MNT or in WTR
 		do {
-			temp->xpos = getrandom(0, world_col - 1);
-			temp->ypos = getrandom(0, world_row - 1);
+			temp->xpos = getrandom (0, world_col - 1);
+			temp->ypos = getrandom (0, world_row - 1);
 		} while (world[world_col * temp->ypos + temp->xpos] != SPC);
-
 		world[world_col * temp->ypos + temp->xpos] = temp->race;
 		
-		temp->vector = getrandom(0, 3);
-		temp->size = getrandom(L_SIZE, H_SIZE);
-		temp->attack = getrandom(L_SKILL, H_SKILL) / 2;
-		temp->defend = getrandom(L_SKILL, H_SKILL) / 2;
+		temp->vector = getrandom (0, 3);
 		
+		temp->size = getrandom (L_SIZE, H_SIZE);
+		temp->attack = getrandom (L_SKILL, H_SKILL) / 2;
+		temp->defend = getrandom (L_SKILL, H_SKILL) / 2;
 		while ((temp->attack + temp->defend) > temp->size)
 		{
 			if (--temp->attack < L_SKILL)
@@ -52,7 +36,6 @@ void start (void)
 			if (--temp->defend < L_SKILL)
 				temp->defend = L_SKILL;
 		}
-		
 		if ((temp->fov = sqrt (temp->size)) > H_FOV)
 			temp->fov = H_FOV;
 
@@ -63,11 +46,10 @@ void start (void)
 		for (loop2 = 0; loop2 < 256; loop2++)
 		{
 			if (is_bug ((char)loop2))
-				temp->things[loop2] = getrandom(-ID, ID);
+				temp->things[loop2] = getrandom (-ID, ID);
 			else
 				temp->things[loop2] = 0;
 		}
-		
 		temp->things[FOOD3] = FOOD_VAL;
 		
 		if (loop == 1)
@@ -77,13 +59,9 @@ void start (void)
 			x->next = temp;
 			temp->prev = x;
 		}
-		
 		x = temp;
 	}
-	
 	temp->next = bugs;
 	bugs->prev = temp;
-	
 	return;
 }
-
